IncompleteUtf8

Struct IncompleteUtf8 

pub struct IncompleteUtf8 {
    pub buffer: [u8; 4],
    pub buffer_len: u8,
}

Fields

buffer: [u8; 4]buffer_len: u8

Implementations

Source

impl IncompleteUtf8

fn new(bytes: &[u8]) -> Self

fn take_buffer(&mut self) -> &[u8]

fn try_complete_offsets( &mut self, input: &[u8], ) -> (usize, Utf8CompletionResult)

Consumes bytes from the input and attempts to form a valid utf8 codepoint.

Returns how many bytes were consumed and whether a valid code point was found.

pub fn try_to_complete_codepoint<'input>( &mut self, input: &'input [u8], ) -> Option<(Result<&str, &[u8]>, &'input [u8])>

Attempts to complete the codepoint given the bytes from input.

Returns None if more input is required to complete the codepoint. In this case, no input is consumed.

Otherwise, returns either the decoded &str or malformed &[u8] and the remaining input.

pub fn try_complete<A, F>( &mut self, input: Tendril<Bytes, A>, push_utf8: F, ) -> Result<Tendril<Bytes, A>, ()>
where A: Atomicity, F: FnMut(Tendril<UTF8, A>),